settings.prc = false;
settings.tex = "pdflatex";
settings.render = 0;
settings.outformat = "pdf";
texpreamble("\usepackage[tt=false, type1=true]{libertine}\usepackage[libertine]{newtxmath}");

import three;
size(200);
size3(200);

defaultpen(1);
pen blackpen = black + 1bp;

currentprojection = orthographic(camera=(5.5, 3, 1), up=Z, target=O, zoom=0.7);

triple A = dir(0.0,0.0);
triple B = dir(90.0,0.0);
triple C = dir(90.0,90.0);
triple ACmid = dir(30, 90);
triple ABmid = dir(30, 0);
triple BCmid = dir(90, 45);
pair targetCoord = (70, 60);
triple target = dir(targetCoord.x, targetCoord.y);
triple targetExt = dir(90 - aTan(Tan(90 - targetCoord.x) / Sin(90 - targetCoord.y) * Sin(45)), 45);
triple mid = point(arc(O, C, ABmid, CCW), intersect(arc(O, C, ABmid, CCW), arc(O, B, ACmid, CCW))[0]);

void markRightAngle(triple v, guide3 gright, guide3 gleft, real arcdist, pen arcpen=currentpen) {
  triple t = arcpoint(gright, arcdist); 
  triple s = arcpoint(gleft, arcdist);
  triple corner = midpoint(arc(O, arcpoint(gright, arcdist * 2), arcpoint(gleft, arcdist * 2), CCW));
  draw(arc(O, t, corner, CCW), arcpen);
  draw(arc(O, s, corner, CCW), arcpen);
}

void markAngle(string lab, triple v, guide3 gright, guide3 gleft, real arcdist, pen arcpen=currentpen) {
  triple t, s;
  t = arcpoint(gright, arcdist); 
  s = arcpoint(gleft, arcdist);
  draw(arc(v, t, s, cross(t - v, s - v), CCW), arcpen);
  label("$" + lab + "$", (v + t + s) / 3, arcpen);
}

// Mark right angle
markRightAngle(BCmid, arc(O, BCmid, A, CCW), arc(O, BCmid, C, CCW), 0.1, blackpen);

// Draw triangles
draw(arc(O, BCmid, C, CCW), blackpen+1.5bp);
draw(arc(O, mid, BCmid, CCW), blackpen+1.5bp);
draw(arc(O, C, mid, CCW), blackpen+1.5bp);
draw(arc(O, mid, target, CCW), blackpen+1.5bp);
draw(arc(O, C, target, CCW), blackpen+1.5bp);
draw(arc(O, targetExt, target, CCW), blackpen+1.5bp); // FIXME: change line style?

// Draw dots
dot(mid);
dot(BCmid);
dot(target);
dot(targetExt);
dot(C);

// Mark angles
markAngle("$$", C, arc(O, C, target, CCW), arc(O, C, mid, CCW), 0.21, blackpen);
label("$\gamma$", project(dir(82.5, 83)));
markAngle("$\delta$", C, arc(O, C, BCmid, CCW), arc(O, C, target, CCW), 0.17, blackpen);
markAngle("$$", mid, arc(O, mid, BCmid, CCW), arc(O, mid, target, CCW), 0.21, blackpen);
label("$\alpha$", project(dir(49.5, 48)));
markAngle("$$", mid, arc(O, mid, target, CCW), arc(O, mid, C, CCW), 0.21, blackpen);
label("$\beta$", project(dir(48, 54)));
markAngle("$$", targetExt, arc(O, targetExt, target, CCW), arc(O, targetExt, mid, CCW), 0.08, blackpen);
label("$\epsilon$", project(dir(62.6, 45.2)), NE);

// Add labels
label("$H$", project(BCmid), SW);
label("$F$", project(C), SE);
label("$a$", project(dir(67, 43)), W);
label("$G$", project(mid), NW);
label("$b$", project(dir(90.0, 67.5)), S);
label("$c$", project(dir(60, 72)), NE);
label("$r$", project(dir(60, 56)), NE);
label("$x$", project(dir(75, 70)), N);
label("$y$", project(dir(66, 52)), S);
