settings.prc = false;
settings.tex = "pdflatex";
settings.render = 0;
settings.outformat = "pdf";
texpreamble("\usepackage[tt=false, type1=true]{libertine}\usepackage[libertine]{newtxmath}");

import three;
size(200);
size3(200);

defaultpen(1);
pen graypen = gray + 1bp;
pen blackpen = black + 1bp;

currentprojection = orthographic(camera=(5.5, 3, 1), up=Z, target=O, zoom=0.7);

triple A = dir(0.0,0.0);
triple B = dir(90.0,0.0);
triple C = dir(90.0,90.0);
triple ACmid = dir(30, 90);
triple ABmid = dir(30, 0);
triple BCmid = dir(90, 45);
triple mid = point(arc(O, C, ABmid, CCW), intersect(arc(O, C, ABmid, CCW), arc(O, B, ACmid, CCW))[0]);

void markRightAngle(triple v, guide3 gright, guide3 gleft, real arcdist, pen arcpen=currentpen) {
  triple t = arcpoint(gright, arcdist); 
  triple s = arcpoint(gleft, arcdist);
  triple corner = midpoint(arc(O, arcpoint(gright, arcdist * 2), arcpoint(gleft, arcdist * 2), CCW));
  draw(arc(O, t, corner, CCW), arcpen);
  draw(arc(O, s, corner, CCW), arcpen);
}

void markAngle(string lab, triple v, guide3 gright, guide3 gleft, real arcdist, pen arcpen=currentpen, triple shift=(0, 0, 0)) {
  triple t, s;
  t = arcpoint(gright, arcdist);
  s = arcpoint(gleft, arcdist);
  draw(arc(v, t, s, cross(t - v, s - v), CCW), arcpen);
  if (lab != "")
    label("$" + lab + "$", (v + t + s) / 3 + shift, arcpen);
}

// Mark right angles
markRightAngle(ACmid, arc(O, ACmid, C, CCW), arc(O, ACmid, B, CCW), 0.1, blackpen);
markRightAngle(ACmid, arc(O, ACmid, A, CCW), arc(O, ACmid, B, CCW), 0.1, blackpen);
markRightAngle(BCmid, arc(O, BCmid, A, CCW), arc(O, BCmid, C, CCW), 0.1, blackpen);
markRightAngle(BCmid, arc(O, BCmid, A, CCW), arc(O, BCmid, B, CCW), 0.1, graypen);
markRightAngle(ABmid, arc(O, ABmid, C, CCW), arc(O, ABmid, B, CCW), 0.1, graypen);
markRightAngle(ABmid, arc(O, ABmid, C, CCW), arc(O, ABmid, A, CCW), 0.1, graypen);

// Mark corners
markRightAngle(C, arc(O, C, A, CCW), arc(O, C, B, CCW), 0.1, graypen);
markRightAngle(B, arc(O, B, A, CCW), arc(O, B, C, CCW), 0.1, graypen);
markRightAngle(A, arc(O, A, C, CCW), arc(O, A, B, CCW), 0.1, graypen);

// Draw and label target point
triple target = dir(70, 70);
draw(arc(O, mid, target, CCW), graypen);
markAngle("", mid, arc(O, mid, target, CCW), arc(O, mid, BCmid, CCW), 0.3, graypen, (0, 0.01, -0.01));
dot(target, gray);
label("$(r, \theta)$", project(dir(target)), SW, heavygray);

// Draw triangles
draw(arc(O, A, B, CCW), graypen);
draw(arc(O, B, BCmid, CCW), graypen);
draw(arc(O, BCmid, C, CCW), blackpen+1.5bp);
draw(arc(O, C, A, CCW), blackpen+1.5bp);
draw(arc(O, A, BCmid, CCW), blackpen+1.5bp);
draw(arc(O, B, mid, CCW), graypen);
draw(arc(O, mid, ABmid, CCW), graypen);
draw(arc(O, mid, ACmid, CCW), blackpen+1.5bp);
draw(arc(O, C, mid, CCW), blackpen+1.5bp);

// Draw dots
dot(mid);
dot(BCmid);
dot(ACmid);
dot(A);
dot(C);

// Mark other angles
markAngle("\psi_0", mid, arc(O, mid, A, CCW), arc(O, mid, ACmid, CCW), 0.21, black, (0, 0, 0.005));
markAngle("\psi_1", mid, arc(O, mid, ACmid, CCW), arc(O, mid, C, CCW), 0.21, black, (0, 0.02, 0.02));
markAngle("\psi_0", mid, arc(O, mid, C, CCW), arc(O, mid, BCmid, CCW), 0.21, black, (0, 0.01, -0.02));
markAngle("\rho", C, arc(O, C, mid, CCW), arc(O, C, B, CCW), 0.22, black, (0, -0.025, 0));

// Add labels
label("$A$", project(A), NW);
label("$B$", project(BCmid), SW);
label("$C$", project(C), SE);
label("$\phi_0$", project(dir(60, 45)), SW);
label("$D$", (project(mid).x - 0.03, project(mid).y - 0.02), W);
label("$E$", project(ACmid), NE);
label("$\pi / 4$", project(dir(90.0, 67.5)), S);
